@@ -9,9 +9,8 @@ def custom_measure_energy():
 
 @measure_energy(handler=csv_handler)
 def custom_csv_handler():
-# Instructions to be evaluated.
-
-    for _ in range(100):
+    print('Trigger custom csv handler function')
+    for _ in range(10):
         custom_csv_handler()
 
 csv_handler.save_data()
